kmeansruns: k-means clustering with several random initializations
Description
This calls the function kmeans to perform a k-means
clustering, but initializes the k-means algorithm several times with
random points from the data set as means. Furthermore, it is more
robust against the occurrence of empty clusters in the algorithm.